import re

EMAIL_USER_REGEX = r"(^[-!#$%&'*+/=?^_`{}|~0-9A-Z]+(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*\Z" \
                   '|^"([\001-\010\013\014\016-\037!#-\[\]-\177]|\\[\001-\011\013\014\016-\177])*"\Z)'
EMAIL_USER_REGEX_COMPILED = re.compile(EMAIL_USER_REGEX, re.IGNORECASE)

EMAIL_DOMAIN_REGEX = r'((?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+)(?:[A-Z0-9-]{2,63}(?<!-))\Z'
EMAIL_DOMAIN_REGEX_COMPILED = re.compile(EMAIL_DOMAIN_REGEX, re.IGNORECASE)


def valid_email(email):
    if not email or '@' not in email:
        return False

    user_part, domain_part = email.rsplit('@', 1)

    # validate user part
    if not EMAIL_USER_REGEX_COMPILED.match(user_part):
        return False

    # validate domain part
    if not EMAIL_DOMAIN_REGEX_COMPILED.match(domain_part):
        return False

    return True


from alas_ce0.common.client_base import ApiClientBase


class TestClient(ApiClientBase):
    entity_endpoint_base_url = '/test'

    def get_labels_content_by_code(self, delivery_order_code):
        params = {
            'delivery_order_code': delivery_order_code,
        }
        result = self.http_post_json(self.entity_endpoint_base_url + '/render/generate_by_code', params)

        if result.response.status == 200:
            return result.content["result"]

        return None

    def get_labels_content(self, delivery_order_id):
        params = {
            'delivery_order_id': delivery_order_id,
        }
        result = self.http_post_json(self.entity_endpoint_base_url + '/render/generate', params)
        if result.response.status == 200:
            return result.content["result"]

        return None




import json

from alas_ce0.management.configuration import ConfigurationClient


def get_parnet_config(config, partner):

    config = json.loads(ConfigurationClient(**config).get('integration-api.json').content)

    partner_config = filter(lambda x: x['partner'] == partner, config)[0]

    if "comune_mapping" not in partner_config:
        partner_config.update({'comune_mapping': {}})

    return partner_config


def get_parnet_config_env(config, partner, env):

    config = json.loads(ConfigurationClient(**config).get('integration-api.json').content)

    partner_config = filter(lambda x: x['partner'] == partner, config)[0]

    if "comune_mapping" not in partner_config:
        partner_config.update({'comune_mapping': {}})

    parnet_config_env = filter(lambda x: x['name'] == env, partner_config["environments"])[0]
    return parnet_config_env
